Colour - Changes
================

Changes
=======

The releases changes are available on Github: https://github.com/colour-science/colour/releases

About
-----

| **Colour** by Colour Developers - 2013 - 2014
| Copyright © 2013 - 2014 – Colour Developers – `colour-science@googlegroups.com <colour-science@googlegroups.com>`_
| This software is released under terms of New BSD License: http://opensource.org/licenses/BSD-3-Clause
| `http://github.com/colour-science/colour <http://github.com/colour-science/colour>`_
